//----------------------------------------------------------
//
// Speakjet control codes from July 27, 2004 version of Speakjet Manual
// Based on PIC assembler source by Doug Elliott, VA3DAE
// Modified to Microchip C18 source by Eric Pierce, VA3EP
// www.va3ep.net
//
//----------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//----------------------------------------------------------
//
//Phoneme decimal-code  //Sample-Words Msec. Phoneme-Type
//------- ----------- ----------------------- -------- ---------------------
//
//
// control functions (binary values in control character section of ASCII codeset)
//
//---- pauses
#define _p0 0		      // 0 msec
#define _p1 1		      // 100 msec including rampdown
#define _p2 2		      // 200 msec including rampdown
#define _p3 3		      // 700 msec after silence
#define _p4 4		      // 30 msec after silence
#define _p5 5		      // 60 msec after silence
#define _p6 6		      // 90 msec after silence
//---- parameter controls
#define _fast 7		    // 0.5 * default duration
#define _slow 8		    // 1.5 * default duration
#define _high 14	    // or stress
#define _stress 14
#define _low 15		    // or relax
#define _relax 15
#define _wait 16	    // for SCP start command or event input
#define _volx 20	    // 0 <  X <  127. default   96
#define _speedx 21	  // 0 <  X <  127. default   114
#define _pitchx 22	  // unit is Hz. 0 <  X <  255. default   88
#define _bendx 23	    // 0 (deep-hollow) <  X <  15 (high metallic). default 5
#define _portctrx 24	// specify Speakjet or user control of I/O bits (0 - 7, deflt   7)
#define _portx 25	    // set programmable I/O port bit values, default   0
#define _reptx 26	    // nomber of repetition for nexty control code. 0 <  X <  255
#define _callx 28	    // call EPROM phrase X, max 3 level nesting
#define _gotox 29	    // goto EPROM phrase X and play it
#define _delayx 30	  // delay X * 10 Msec. 0 <  X <  255
#define _defaults 31	// restore volume, speed, pitch and bend to default values
//
//
// serial control protcool (SCP) (in printing character portion of ASCII codeset)
//
#define scp_esc 0x5C	  // backslash is escape character for scp command sequence
#define scp_sel0 '0'	  // \0 command puts speakjet with node number 0 (default) into scp mode
#define scp_exit 'X'	  // scp command X causes speakjet to exit from scp mode
#define scp_verify 'V'	// scp V command causes speakjet to enunciate "Ready"
#define scp_clrinp 'R'	// causes scp's 16 byte numeric input buffer to be cleared
#define scp_memtyp 'H'	// uses numeric argument to set memory type (0 reg, 32 EEPROM)
#define scp_memaddr 'J'	// uses numeric argument to set current memory address
#define scp_memwrt 'N'	// uses numeric argument to set contents of current memory address
#define scp_reset 'W'	  // does a hardware reset on speakjet hardware, and exits from scp mode
#define scp_stop 'S'	  // sets wait flag to 1, and ignores any data in 64 byte input buffer
#define scp_start 'T'	  // clears wait flag, and enunciates any data in 64 byte input buffer
//ASCII for hex digita	// used for numeric command arguments. eg. '0  0x30   48 decimal
//
//
// phonemes and special sounds. (8 bit binary values with high order bit on, 'above' 7 bit ASCII.)
//
//-------- voiced vowels
#define _iy 128		//See, Even, Feed 	70 Voiced Long Vowel
#define _ih 129 	//Sit, Fix, Pin 	70 Voiced Short Vowel
#define _ey 130 	//Hair, Gate, Beige 	70 Voiced Long Vowel
#define _eh 131 	//Met, Check, Red 	70 Voiced Short Vowel
#define _ay 132 	//Hat, Fast, Fan 	70 Voiced Short Vowel
#define _ax 133 	//Cotten 		70 Voiced Short Vowel
#define _ux 134 	//Luck, Up, Uncle 	70 Voiced Short Vowel
#define _oh 135 	//Hot, Clock, Fox 	70 Voiced Short Vowel
#define _aw 136 	//Father, Fall 		70 Voiced Short Vowel
#define _ow 137 	//Comb, Over, Hold 	70 Voiced Long Vowel
#define _uh 138 	//Book, Could, Should 	70 Voiced Short Vowel
#define _uw 139 	//Food, June 		70 Voiced Long Vowel
//-------- voiced nasals
#define _mm 140 	//Milk, Famous, 	70 Voiced Nasal
#define _ne 141 	//Nip, Danger, Thin 	70 Voiced Nasal
#define _no 142 	//No, Snow, On 		70 Voiced Nasal
#define _nge 143	//Think, Ping 		70 Voiced Nasal
#define _ngo 144 	//Hung, Song 		70 Voiced Nasal
//-------- voiced resonates
#define _le 145 	//Lake, Alarm, Lapel 	70 Voiced Resonate
#define _lo 146 	//Clock, Plus, Hello 	70 Voiced Resonate
#define _ww 147 	//Wool, Sweat 		70 Voiced Resonate
#define _rr 148 	//Ray, Brain, Over 	70 Voiced Resonate
//-------- voiced R colour vowels
#define _iyrr 149 	//Clear, Hear, Year 	200 Voiced R Color Vowel
#define _eyrr 150 	//Hair, Stair, Repair 	200 Voiced R Color Vowel
#define _axrr 151 	//Fir, Bird, Burn 	190 Voiced R Color Vowel
#define _awrr 152 	//Part, Farm, Yarn 	200 Voiced R Color Vowel
#define _owrr 153 	//Corn, Four, Your 	185 Voiced R Color Vowel
//-------- voiced dipthongs
#define _eyiy 154 	//Gate, Ate, Ray 	165 Voiced Diphthong
#define _ohiy 155 	//Mice, Fight, White 	200 Voiced Diphthong
#define _owiy 156 	//Boy, Toy, Voice 	225 Voiced Diphthong
#define _ohih 157 	//Sky, Five, I 		185 Voiced Diphthong
#define _iyeh 158 	//Yes, Yarn, Million 	170 Voiced Diphthong
#define _ehll 159 	//Saddle, Angle, Spell 	140 Voiced Diphthong
#define _iyuw 160 	//Cute, Few, 		180 Voiced Diphthong
#define _axuw 161 	//Brown,Clown,Thousand	170 Voiced Diphthong
#define _ihww 162 	//Two, New, Zoo 	170 Voiced Diphthong
#define _ayww 163 	//Our, Ouch, Owl 	200 Voiced Diphthong
#define _owww 164 	//Go, Hello, Snow 	131 Voiced Diphthong
//-------- voiced affricate and frictives
#define _jh 165 	//Dodge, Jet, Savage 	70 Voiced Affricate
#define _vv 166 	//Vest, Even, 		70 Voiced Fictive
#define _zz 167 	//Zoo, Zap 		70 Voiced Fictive
#define _zh 168 	//Azure, Treasure 	70 Voiced Fictive
#define _dh 169 	//There, That, This 	70 Voiced Fictive
//-------- voiced stops
#define _be 170 	//Bear, Bird, Beed 	45 Voiced Stop
#define _bo 171 	//Bone, Book Brown 	45 Voiced Stop
#define _eb 172 	//Cab, Crib, Web 	10 Voiced Stop
#define _ob 173 	//Bob, Sub, Tub 	10 Voiced Stop
#define _de 174 	//Deep, Date, Divide 	45 Voiced Stop
#define _do 175 	//Do, Dust, Dog 	45 Voiced Stop
#define _ed 176 	//Could, Bird 		10 Voiced Stop
#define _od 177 	//Bud, Food 		10 Voiced Stop
#define _ge 178 	//Get, Gate, Guest, 	55 Voiced Stop
#define _go 179 	//Got, Glue, Goo 	55 Voiced Stop
#define _eg 180 	//Peg, Wig 		55 Voiced Stop
#define _og 181 	//Dog, Peg 		55 Voiced Stop
//-------- voiceless affricate and fricatives
#define _ch 182 	//Church,Feature,March	70 Voiceless Affricate
#define _he 183 	//Help, Hand, Hair 	70 Voiceless Fricative
#define _ho 184 	//Hoe, Hot, Hug 	70 Voiceless Fricative
#define _wh 185 	//Who, Whale, White 	70 Voiceless Fricative
#define _ff 186 	//Food, Effort, Off 	70 Voiceless Fricative
#define _se 187 	//See, Vest, Plus 	40 Voiceless Fricative
#define _so 188 	//So, Sweat 		40 Voiceless Fricative
#define _sh 189 	//Ship, Fiction, Leash 	50 Voiceless Fricative
#define _th 190 	//Thin, month 		40 Voiceless Fricative
//-------- voiceless stops
#define _tt 191 	//Part, Little, Sit 	50 Voiceless Stop
#define _tu 192 	//To, Talk, Ten 	70 Voiceless Stop
#define _ts 193 	//Parts, Costs, Robots 	170 Voiceless Stop
#define _ke 194 	//Can't, Clown, Key 	55 Voiceless Stop
#define _ko 195 	//Comb, Quick, Fox 	55 Voiceless Stop
#define _ek 196 	//Speak, Task 		55 Voiceless Stop
#define _ok 197 	//Book, Took, October 	45 Voiceless Stop
#define _pe 198 	//People, Computer 	99 Voiceless Stop
#define _po 199 	//Paw, Copy 		99 Voiceless Stop
//--------- robot sounds
#define _r0 200 	//doop			80 Robot
#define _r1 201 	//dweep			80 Robot
#define _r2 202 	//dwip			80 Robot
#define _r3 203 	//dwip - higher		80 Robot
#define _r4 204 	//dwip - higher		80 Robot
#define _r5 205 	//dwip - higher		80 Robot
#define _r6 206 	//dwip - higher		80 Robot
#define _r7 207 	//dwip - higher		80 Robot
#define _r8 208 	//dwip - higher		80 Robot
#define _r9 209 	//dwip - higher		80 Robot
#define _a0 210 	//dwee -oop		300 Alarm
#define _a1 211 	//bwa..ah..ee		101 Alarm
#define _a2 212 	//bwi..ah..ooo		102 Alarm
#define _a3 213 	//bwa..at		540 Alarm
#define _a4 214 	//bweep			530 Alarm
#define _a5 215 	//oo-ah-oo		500 Alarm
#define _a6 216 	//bwink			135 Alarm
#define _a7 217 	//boo..wah		600 Alarm (submarine dive signal)
#define _a8 218 	//woo weep		300 Alarm
#define _a9 219 	//dee..you		250 Alarm
#define _b0 220 	//bink			200 Beeps 
#define _b1 221 	//dwee..you		270 Beeps
#define _b2 222 	//dah wink		280 Beeps
#define _b3 223 	//eee onk		260 Beeps
#define _b4 224 	//doo a wit		300 Beeps
#define _b5 225 	//dweek			100 Beeps
#define _b6 226 	//(warble)		104 Beeps
#define _b7 227 	//blee ick		100 Beeps
#define _b8 228 	//wee..you		270 Beeps
#define _b9 229 	//buhbeebup		262 Beeps
#define _c0 230 	//yerp (warbled)	160 Biological
#define _c1 231 	//why.(warbled)		300 Biological
#define _c2 232 	//orp ik (warbled)	182 Biological
#define _c3 233 	//(cricket)		120 Biological
#define _c4 234 	//oo wee (warbled)	175 Biological
#define _c5 235 	//ee you		350 Biological
#define _c6 236 	//ya wa (warbled)	160 Biological
#define _c7 237 	//wa ooo (warbled)	260 Biological
#define _c8 238 	//brit (warbled)	95 Biological
#define _c9 239 	//bri (warbled)		75 Biological
#define _d0 240 	//telephone 0 button	95 DTMF
#define _d1 241 	//telephone 1 button	95 DTMF
#define _d2 242 	//telephone 2 button	95 DTMF
#define _d3 243 	//telephone 3 button	95 DTMF
#define _d4 244 	//telephone 4 button	95 DTMF
#define _d5 245 	//telephone 5 button	95 DTMF
#define _d6 246 	//telephone 6 button	95 DTMF
#define _d7 247 	//telephone 7 button	95 DTMF
#define _d8 248 	//telephone 8 button	95 DTMF
#define _d9 249 	//telephone 9 button	95 DTMF
#define _d10 250 	//telephone * button	95 DTMF
#define _d11 251 	//telephone # button	95 DTMF
#define _m0 252 	//Sonar Ping 		125 Miscellaneous
#define _m1 253 	//Pistol Shot 		250 Miscellaneous
#define _m2 254 	//WOW 			530 Miscellaneous
#define _eophrase 255	//end of phrase in Speakjet's EEProm storage area
//
